-- MySQL dump 10.14  Distrib 5.5.65-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: asterisk
-- ------------------------------------------------------
-- Server version	5.5.65-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `fax_store`
--

DROP TABLE IF EXISTS `fax_store`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `fax_store` (
  `faxid` varchar(25) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `user` varchar(25) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `dir` varchar(10) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `date` varchar(12) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `header` varchar(80) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `stationid` varchar(50) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `callid` varchar(75) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `dest` varchar(20) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `status` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `pages` varchar(10) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `file` varchar(100) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `new` varchar(10) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `finished` varchar(2) COLLATE utf8mb4_unicode_ci DEFAULT '1',
  `pid` int(11) DEFAULT NULL,
  `channel` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  PRIMARY KEY (`faxid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `fax_store`
--

LOCK TABLES `fax_store` WRITE;
/*!40000 ALTER TABLE `fax_store` DISABLE KEYS */;
/*!40000 ALTER TABLE `fax_store` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `faxpro_hook_core`
--

DROP TABLE IF EXISTS `faxpro_hook_core`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `faxpro_hook_core` (
  `page` varchar(150) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `id` varchar(150) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  `status` varchar(255) COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  PRIMARY KEY (`page`,`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `faxpro_hook_core`
--

LOCK TABLES `faxpro_hook_core` WRITE;
/*!40000 ALTER TABLE `faxpro_hook_core` DISABLE KEYS */;
/*!40000 ALTER TABLE `faxpro_hook_core` ENABLE KEYS */;
UNLOCK TABLES;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2025-11-08 23:26:03
